@@ -23,7 +23,7 @@ with qw(
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 use version;
-our $VERSION = '0.32';
+our $VERSION = '0.34';
 $VERSION = eval $VERSION;    ## no critic
 
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
@@ -33,10 +33,8 @@ use Cwd qw(getcwd);
 use Data::Printer {caller_info => 1,};
 use File::Find qw(find);
 use File::Spec;
-use MetaCPAN::API;
 use Module::CoreList;
 use PPI;
-use Perl::PrereqScanner;
 use Term::ANSIColor qw( :constants colored colorstrip );
 use Try::Tiny;
 use Tie::Static qw(static);
@@ -161,9 +159,15 @@ sub first_package_name {
 
 	# We will assume the first package found is our Package Name, pot lock :)
 	# due to Milla not being a dist we go and get dist-name
+
 	try {
-		my $mcpan_module_info = $self->mcpan->module($self->package_names->[0]);
-		my $distribution_name = $mcpan_module_info->{distribution};
+		my $is_package_name = $self->package_names->[0];
+		$is_package_name =~ s{::}{-}g;
+
+		# MetaCPAN::Client expects hyphens in distribution search
+		my $mcpan_dist_info = $self->mcpan->distribution($is_package_name);
+		my $distribution_name = $mcpan_dist_info->name();
+
 		$distribution_name =~ s{-}{::}g;
 		$self->_set_distribution_name($distribution_name);
 	}
@@ -236,8 +240,8 @@ sub _find_runtime_requirments {
 	my $self     = shift;
 	my $filename = $_;
 
-	return if $self->is_perlfile($filename) eq FALSE;
-
+	return if $self->is_perlfile($filename) == FALSE;
+ 
 	my $relative_dir = $File::Find::dir;
 	$relative_dir =~ s/$Working_Dir//;
 	$self->_set_looking_infile(File::Spec->catfile($relative_dir, $filename));
@@ -275,7 +279,8 @@ sub _find_runtime_requirments {
 				$module =~ s/[']$//;
 
 				next if $module =~ m/^Dist::Zilla::Role::PluginBundle/;
-				next if $module =~ m{\A[-|:|\d|a-z]};
+				next if $module =~ m{\A[-|:|\d]};
+				next if $module !~ m{\A(?:[[a-zA-Z])};
 				next if $module =~ m{[.|$|\\|/|\-|\[|%|@|]};
 				next if $module eq NONE;
 
@@ -349,7 +354,7 @@ sub _find_test_develop_requirments {
 		= ($directorie =~ m/xt$/) ? 'DevelopRequires' : 'TestSuggests';
 	$self->_set_xtest(TRUE) if $directorie =~ m/xt$/;
 
-	return if $self->is_perlfile($filename) eq FALSE;
+	return if $self->is_perlfile($filename) == FALSE;
 
 	my $relative_dir = $File::Find::dir;
 	$relative_dir =~ s/$Working_Dir//;
@@ -563,24 +568,24 @@ sub _in_corelist {
 	my $self   = shift;
 	my $module = shift;
 
-	#return 1 if defined $self->{modules}{$module}{corelist};
+	#return TRUE (1) if defined $self->{modules}{$module}{corelist};
 
 	# hash with core modules to process regardless
 	my $ignore_core = {'File::Path' => 1, 'Test::More' => 1,};
 
 	if (!$ignore_core->{$module}) {
 
-		if (Module::CoreList->first_release($module)) {
+		if ( Module::CoreList->first_release($module) ) {
 			$self->{modules}{$module}{corelist} = 1;
-			return 1;
+			return TRUE;
 		}
 		else {
 			$self->{modules}{$module}{corelist} = 0;
-			return 0;
+			return FALSE;
 		}
 	}
 
-	return 0;
+	return FALSE;
 }
 
 
@@ -623,7 +628,7 @@ sub _check_mojo_core {
 }
 
 #######
-# get module version using metacpan_api
+# get module version using metacpan_client (mc)
 #######
 sub get_module_version {
 	my $self         = shift;
@@ -631,48 +636,42 @@ sub get_module_version {
 	my $require_type = shift || undef;
 	my $cpan_version;
 	my $found = 0;
-	my $dist;
+	my $mcc;
 
 	p $module if $self->debug;
 
 	try {
-		$module =~ s/::/-/g;
 
-		# quick n dirty, get version number if module is classed as a distribution in metacpan
-		my $mod = $self->mcpan->release(distribution => $module);
-		$cpan_version = $mod->{version_numified};
+		$mcc = $self->mcpan->module($module);
+
+		$cpan_version = $mcc->version_numified();
 		p $cpan_version if $self->debug;
 
 		$found = 1;
-	}
-	catch {
-		try {
-			$module =~ s/-/::/g;
-			my $mcpan_module_info = $self->mcpan->module($module);
-			$dist = $mcpan_module_info->{distribution};
+	};
+	try {
+		my $dist_name = $mcc->distribution();
+		$dist_name =~ s/-/::/g;
+
+		if ($dist_name eq 'perl') {
 
 			# mark all perl core modules with either 'core' or '0'
-			if ($dist eq 'perl') {
-				$cpan_version = 'core';
-				$found        = 1;
-			}
-		};
-		if ($found == 0) {
-			try {
-				my $mod = $self->mcpan->release(distribution => $dist);
+			$cpan_version = 'core';
+			$found        = 1;
+		}
+		elsif ($module =~ m/^inc::/) {
 
-				# This is where we add a dist version to a knackered module
-				$cpan_version = $mod->{version_numified};
-				$found        = 1;
+			#skip saving inc::Module::Install from Role-Output
+			return $cpan_version;
+		}
+		elsif ($dist_name ne $module) {
 
-				#skip saving inc::Module::Install from Role-Output
-#				return $cpan_version if $module =~ m/^inc::/;
-
-				$self->{modules}{$module}{distribution} = $dist;
-				$self->mod_in_dist($dist, $module, $require_type,
-					$mod->{version_numified})
-					if $require_type;
-			}
+			# This is where we add a dist version to a knackered module
+			$self->{modules}{$module}{distribution} = $dist_name;
+			$self->mod_in_dist($dist_name, $module, $require_type,
+				$mcc->version_numified())
+				if $require_type;
+			$found = 1;
 		}
 	}
 	finally {
@@ -680,6 +679,7 @@ sub get_module_version {
 		$cpan_version = '!mcpan' if $found == 0;
 	};
 
+	# the following my note be needed any more due to developments in MetaCPAN 
 	# scientific numbers in a version string, O what fun.
 	if ($cpan_version =~ m/\d+e/) {
 
@@ -745,7 +745,7 @@ App::Midgen - Check B<RuntimeRequires> & B<TestRequires> of your package for CPA
 
 =head1 VERSION
 
-This document describes App::Midgen version: 0.32
+This document describes App::Midgen version: 0.34
 
 =head1 SYNOPSIS
 
