@@ -7,7 +7,7 @@ use Moo::Role;
 requires
 	qw( ppi_document debug verbose format xtest _process_found_modules develop meta2 );
 
-our $VERSION = '0.32';
+our $VERSION = '0.34';
 $VERSION = eval $VERSION;    ## no critic
 
 use PPI;
@@ -433,7 +433,7 @@ sub _module_names_ppi_sl {
 				{
 					my $module = $ppi_se->{children}[$_]->content;
 					$module =~ s/(?:['|"])//g;
-					if ($module =~ m/\A[A-Z]/) {
+					if ($module =~ m{\A(?:[a-zA-Z])}) {
 						print "found module - $module\n" if $self->debug;
 						push @{$mn_ref}, $module;
 						$mv_ref->[$#{$mn_ref}] = undef;
@@ -448,7 +448,7 @@ sub _module_names_ppi_sl {
 				{
 					my $version_string = $ppi_se->{children}[$_]->content;
 					$version_string =~ s/(?:['|"])//g;
-					next if $version_string !~ m/\A[\d|v]/;
+					next if $version_string !~ m{\A[\d|v]};
 
 					$version_string
 						= version::is_lax($version_string) ? $version_string : 0;
@@ -488,7 +488,7 @@ includes, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.32
+version: 0.34
 
 
 =head1 METHODS
